"use strict";
// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License.
Object.defineProperty(exports, "__esModule", { value: true });
exports.matMul = exports.createMatmulProgramInfoLoader = void 0;
const util_1 = require("../../util");
const types_1 = require("../types");
const matmul_packed_webgpu_1 = require("./3rd-party/matmul_packed_webgpu");
const createMatmulProgramMetadata = (hasBias, cacheHint) => ({
    name: 'MatMul',
    inputTypes: hasBias ? [types_1.GpuDataType.default, types_1.GpuDataType.default, types_1.GpuDataType.default] :
        [types_1.GpuDataType.default, types_1.GpuDataType.default],
    cacheHint
});
const createMatmulProgramInfoLoader = (inputs, activationAttributes, outputShape, reshapedOutputShape) => {
    const metadata = createMatmulProgramMetadata(inputs.length > 2, activationAttributes.activationCacheKey);
    return {
        ...metadata,
        get: () => (0, matmul_packed_webgpu_1.createMatmulProgramInfo)(metadata, inputs, activationAttributes, outputShape, reshapedOutputShape)
    };
};
exports.createMatmulProgramInfoLoader = createMatmulProgramInfoLoader;
const validateInputs = (inputs) => {
    if (!inputs || inputs.length !== 2) {
        throw new Error('MatMul requires 2 inputs.');
    }
    if (inputs[0].dims[inputs[0].dims.length - 1] !== inputs[1].dims[inputs[1].dims.length - 2]) {
        throw new Error('shared dimension does not match.');
    }
    if (inputs[0].dataType !== 1 /* DataType.float */ || inputs[1].dataType !== 1 /* DataType.float */) {
        throw new Error('inputs should be float type');
    }
};
const matMul = (context) => {
    validateInputs(context.inputs);
    const outputShape = util_1.BroadcastUtil.calcShape(context.inputs[0].dims, context.inputs[1].dims, true);
    if (!outputShape) {
        throw new Error('Can\'t use matmul on the given tensors');
    }
    context.compute((0, exports.createMatmulProgramInfoLoader)(context.inputs, { activation: '', activationCacheKey: '' }, outputShape));
};
exports.matMul = matMul;
//# sourceMappingURL=matmul.js.map